@@ -317,7 +317,7 @@ class Installer(ProviderInstaller):
                   'idp subject salt': subject_salt}
         opt_dam = opts.get('openidc_default_attribute_mapping')
         if opt_dam:
-            config['default attribute mapping'] = opt_dam
+            config['default attribute mapping'] = json.dumps(opt_dam)
         po.save_plugin_config(config)
 
         # Update global config to add login plugin
